==> light-5.x-1.2.tar.gz: light/page.tpl.php <==
<?php
echo("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"> 
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    <title><?php print $head_title ?></title>
    <?php print $head ?>
    <?php print $styles ?>
    <?php print $scripts ?>
<!--[if IE]>
<style type="text/css"> 
/* place css fixes for all versions of IE in this conditional comment */
.page #sidebar1, .page #sidebar2 { padding-top: 30px; }
.page #mainContent { zoom: 1; padding-top: 15px; }
/* the above proprietary zoom property gives IE the hasLayout it needs to avoid several bugs */
</style>
<![endif]-->
</head>

<body class="page">

<div id="container">
    
    <!-- start #header -->
	<div id="header">
        <div id="logo">
            <h1><a href="<?php print check_url($base_path); ?>"><?php print check_plain($site_name); ?></a></h1>
            <?php if ($site_slogan) { ?><h2><?php print $site_slogan ?></h2><?php } ?>
        </div>
        
        <?php if (isset($primary_links)): ?>
        <div id="navigation">
                        
            <?php 
            //see http://drupal.org/node/140491
           // print theme('links', $primary_links);
            print phptemplate_light_primarylinks($primary_links);
           
            ?>
            
        </div>
        <?php endif; ?>
    
    </div>
    <!-- end #header -->
    
    <!-- start #wrap -->
    <div id="wrap">
        <!-- start #content -->
        <div id="content"> 
      
            <?php if ($mission != ""): ?>
                <div id="mission"><?php print $mission ?></div>
            <?php endif; ?>
                    
            <?php print $header; ?>
            
            <?php if ($title != ""): ?>
                <h2><?php print $title ?></h2>
            <?php endif; ?>
            
            <?php if ($tabs != ""): ?>
                <?php print $tabs ?>
            <?php endif; ?>
            
            <?php if ($help != ""): ?>
                <p id="help"><?php print $help ?></p>
            <?php endif; ?>
            
            <?php if ($messages != ""): ?>
                <?php print $messages ?>
            <?php endif; ?>
            
            <?php print($content) ?>
        
        </div>
        <!-- end #content -->
      
        
        <!-- start #sidebar -->
        <div id="sidebar">
            <!-- is this the front page ? -->
            <?php if ($is_front): ?>
            
                <!-- start #about -->
                <div id="about">
                    <h2>About</h2>
                    <p><img class="left" src="<?php print path_to_theme(); ?>/images/profile.png" width="68px" height="70px" alt="Nick Young" /></p>
                    <p><b><?php print check_plain($site_name); ?></b><br />
                    <?php if ($site_slogan) { print $site_slogan; } ?>
                    <?php
                        $count = db_result(db_query("SELECT COUNT(DISTINCT(n.nid)) FROM {node} n WHERE n.status=1"));
                        echo "There is a total of $count posts ";
                        $count = db_result(db_query("SELECT COUNT(DISTINCT(n.nid)) FROM {node} n WHERE n.type='blog' AND n.status=1", $mytype));
                        echo "($count blog posts).";
                    ?></p>
                </div>
                <!-- end #about -->
                    
                <div style="clear:both;">&nbsp;</div>
                
                <!-- start #rss_feeds -->
                <div id="rss_feeds">
                    <h2>Feed on</h2>
                    <p><?php print l(t('Site RSS'), 'rss.xml', array('title' => t('Site RSS feed'),'class' =>'feed_icon')); ?></p>
                </div>
                <!-- end #rss_feeds -->
                
                <!-- start #meta -->
                <div id="meta">
                    <!-- login / admin / other shortcuts -->
                    <h2>Meta</h2>
                    <!-- see if a user is signed on -->
                    <?php
                    global $user;
                    if (!$user->uid):
                        print(l("Login","user/login") .' / ' .l("Register","user/register")); 
                    endif; ?>	
                    
                    <!-- end if a user is signed on -->
                    <p><a href="/tracker">Recent Posts</a><br />
                    <a href="http://validator.w3.org/check?uri=referer">XHTML 1.1</a><br />
                    <a href="http://jigsaw.w3.org/css-validator/">CSS 2.1</a></p>
                
                </div>
                <!-- end #meta -->

            <?php endif; ?>	
            <!-- end is this the front page ? -->

            <!-- start secondary menu -->
            <?php if ($secondary_links): ?>
                <h2>Section Menu</h2>
                <?php print theme('links', $secondary_links, array('class' => 'links secondary_menu')) ?>
            <?php endif; ?>	
            <!-- end secondary menu -->
            
            <?php if ($sidebar): ?>
                <?php print $sidebar; ?>
            <?php endif; ?>	
        </div>
        <!-- end #sidebar -->
   
    </div>
    <!-- end #wrap -->
  
	<div style="clear:both;">&nbsp;</div>

	
	<!-- This clearing element should immediately follow the #mainContent div in order to force the #container div to contain all child floats --><br class="clearfloat" />
	
    <!-- start #footer -->
	<div id="footer">
		<p><?php print $footer_message ?> | Theme based on <a href="http://vaguedream.com/wordpress-themes/">Light Theme</a></p>
	</div>
    <!-- end #footer -->
</div>
<!-- end #container -->
<?php
print $closure
?>
</body>
</html>

==> light-5.x-1.3.tar.gz: light/page.tpl.php <==
<?php
echo("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n");
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"> 
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
    <title><?php print $head_title ?></title>
    <?php print $head ?>
    <?php print $styles ?>
    <?php print $scripts ?>
<!--[if IE]>
<style type="text/css"> 
/* place css fixes for all versions of IE in this conditional comment */
.page #sidebar1, .page #sidebar2 { padding-top: 30px; }
.page #mainContent { zoom: 1; padding-top: 15px; }
/* the above proprietary zoom property gives IE the hasLayout it needs to avoid several bugs */
</style>
<![endif]-->
</head>

<body class="page">

<div id="container">
    
    <!-- start #header -->
	<div id="header">
        <div id="logo">
            <h1><a href="<?php print check_url($base_path); ?>"><?php print check_plain($site_name); ?></a></h1>
            <?php if ($site_slogan) { ?><h2><?php print $site_slogan ?></h2><?php } ?>
        </div>
        
        <?php if (isset($primary_links)): ?>
        <div id="navigation">
                        
            <?php 
            //see http://drupal.org/node/140491
           // print theme('links', $primary_links);
            print phptemplate_light_primarylinks($primary_links);
            ?>
            
        </div>
        <?php endif; ?>
    
    </div>
    <!-- end #header -->
    
    <!-- start #wrap -->
    <div id="wrap">
        <!-- start #content -->
        <div id="content"> 
      
            <?php if ($mission != ""): ?>
                <div id="mission"><?php print $mission ?></div>
            <?php endif; ?>
                    
            <?php print $header; ?>
            
            <?php if ($title != ""): ?>
                <h2><?php print $title ?></h2>
            <?php endif; ?>
            
            <?php if ($breadcrumb) { ?><div class="breadcrumb"><?php print $breadcrumb ?></div><?php } ?>
            
            <?php if ($tabs != ""): ?>
                <?php print $tabs ?>
            <?php endif; ?>
            
            <?php if ($help != ""): ?>
                <p id="help"><?php print $help ?></p>
            <?php endif; ?>
            
            <?php if ($messages != ""): ?>
                <?php print $messages ?>
            <?php endif; ?>
            
            <?php print($content) ?>
        
        </div>
        <!-- end #content -->
      
        <!-- start #sidebar -->
        <div id="sidebar">
            <?php if ($sidebar): ?>
                <?php print $sidebar; ?>
            <?php endif; ?>	
        </div>
        <!-- end #sidebar -->
   
    </div>
    <!-- end #wrap -->
  
	<div style="clear:both;">&nbsp;</div>

	<!-- This clearing element should immediately follow the #mainContent div in order to force the #container div to contain all child floats --><br class="clearfloat" />
	
    <!-- start #footer -->
	<div id="footer">
		<p><?php print $footer_message ?> | Theme based on <a href="http://wpzone.net/">Light Theme</a></p>
	</div>
    <!-- end #footer -->
</div>
<!-- end #container -->
<?php
print $closure
?>
</body>
</html>
